@@ -1,4 +1,4 @@
-# Copyright 2015 FUJITSU LIMITED
+# Copyright 2015-2017 FUJITSU LIMITED
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -12,32 +12,15 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from oslo_config import cfg
 from oslo_log import log
 from oslo_middleware import base as om
 from webob import response
 
-CONF = cfg.CONF
+from monasca_log_api import conf
+
+CONF = conf.CONF
 LOG = log.getLogger(__name__)
 
-role_m_opts = [
-    cfg.ListOpt(name='path',
-                default='/',
-                help='List of paths where middleware applies to'),
-    cfg.ListOpt(name='default_roles',
-                default=None,
-                help='List of roles allowed to enter api'),
-    cfg.ListOpt(name='agent_roles',
-                default=None,
-                help=('List of roles, that if set, mean that request '
-                      'comes from agent, thus is authorized in the same '
-                      'time'))
-]
-role_m_group = cfg.OptGroup(name='roles_middleware', title='roles_middleware')
-
-CONF.register_group(role_m_group)
-CONF.register_opts(role_m_opts, role_m_group)
-
 _X_IDENTITY_STATUS = 'X-Identity-Status'
 _X_ROLES = 'X-Roles'
 _X_MONASCA_LOG_AGENT = 'X-MONASCA-LOG-AGENT'
@@ -66,7 +49,7 @@ class RoleMiddleware(om.ConfigurableMiddleware):
     exits silently (that is considered a success). Otherwise
     middleware produces JSON response according to following schema
 
-    .. code-block:: json
+    .. code-block:: javascript
 
         {
           'title': u'Unauthorized',
@@ -81,12 +64,15 @@ class RoleMiddleware(om.ConfigurableMiddleware):
         path = /v2.0/log
         default_roles = monasca-user
         agent_roles = monasca-log-agent
+        delegate_roles = admin
 
     Configuration explained:
 
     * path (list) - path (or list of paths) middleware should be applied
     * agent_roles (list) - list of roles that identifies tenant as an agent
     * default_roles (list) - list of roles that should be authorized
+    * delegate_roles (list) - list of roles that are allowed to POST logs on
+                                behalf of another tenant (project)
 
     Note:
         Being an agent means that tenant is automatically authorized.
